@@ -19,6 +19,15 @@ class Episode:
     slug: str
     urn: str
 
+    @property
+    def metadata(self):
+        return {"title" : self.title,
+                "description" : self.description,
+                "episode-number" : self.number,
+                "publish-date" : self.publish_date,
+                "drdk-urn" : self.urn,
+                }
+
     @classmethod
     def from_api_json(cls, data: dict[str, Any], number: int):
         return cls(
